        // Provide a buffer between a Producer and a Consumer.
class Buffer {
        // Wait until an item is available and return it.
    public synchronized int retrieve(){
        while(!itemAvailable()){
            try{
                // Wait to be notified of an item becoming available.
                wait();
            }
            catch(InterruptedException e){
            }
        }
        // Retrieve the item before we notify waiting threads.
        int item = getItem();
        // Consume it.
        setAvailable(false);
        return item;
    }

        // Wait until the buffer is free, then fill it.
    public synchronized void store(int item){
        while(itemAvailable()){
            try{
                // Wait to be notified of the buffer being empty.
                wait();
            }
            catch(InterruptedException e){
            }
        }
        // Fill it.
        setItem(item);
        setAvailable(true);
    }

        // Is there an item in the buffer?
    public synchronized boolean itemAvailable(){
        return available;
    }

        // Public access and mutation is only available
        // through retrieve() and store().
    protected synchronized void setAvailable(boolean a){
        // Determine whether the status is being changed.
        boolean statusChange = a != available;

        available = a;
        if(statusChange){
            // A change in status. Notify a waiting thread.
            notify();
        }
    }

    protected synchronized int getItem(){
        return item;
    }

    protected synchronized void setItem(int i){
        item = i;
    }

    // Whether there is an item in the buffer or not.
    private boolean available = false;
    // The buffered item.
    private int item;
}
