    // Regular debits are made from the account if there are
    // sufficient funds.
    // Allow the user to specify how much they wish to withdraw
    // within the balance of the account.
class SaferATM extends AccountUser implements Runnable {
    SaferATM(Account account){
        super(account);
    }

    public void run(){
        Account account = getAccount();
        SimpleInput keyboard = new SimpleInput();
        final long sleepTime = 100;

        while(true){
            try{
                // Critical section: acquire the lock on the account.
                synchronized(account){
                    // Find out the maximum amount that may be withdrawn.
                    long available = account.getBalance();
                    if(available > 0){
                        System.out.print("You have "+available+
                            " available, how much do you want? ");
                        System.out.flush();
                        // Request the amount from the user.
                        long amount = keyboard.nextLong();
                        // Check its validity.
                        if(amount <= 0){
                            System.out.println("The amount must be positive.");
                        }
                        else if(amount > available){
                            System.out.println("That is too much.");
                        }
                        else{
                            // This should be ok, but ...
                            if(!account.debit(amount)){
                                System.out.println("The debit failed!");
                            }
                        }
                    }
                }
                // The lock has been released.
                Thread.sleep(sleepTime);
            }
            catch(InterruptedException e){
            }
        }
    }
}
